validate_annotation_keys

Function validate_annotation_keys 

pub fn validate_annotation_keys<'a>(
    keys: impl IntoIterator<Item = &'a str>,
) -> Result<Option<AnnotationFamily>, AnnotationKeyError>
Validates a SET/UNSET batch and returns its annotation family.

Empty batches and batches containing only non-annotation keys return None. Annotation keys cannot share a batch with another family or region options. Duplicate keys are rejected only for families that require unique keys.